@@ -3,26 +3,20 @@
 set_optmethod = function(optmethod){
   # Fallbacks for optmethod - checks required packages are installed
   if(optmethod == "mixIP"){
-    if (!requireNamespace("REBayes", quietly = TRUE)) {  # check whether REBayes package is present
-    # If REBayes package missing
+      if (!requireNamespace("REBayes", quietly = TRUE)) {
+          
+    # Check whether REBayes package is present.
+    # If REBayes package missing.
       message("Due to absence of package REBayes, switching to EM algorithm")
       optmethod = "cxxMixSquarem"
     }
   }
   
-  if(optmethod == "cxxMixSquarem"){
-    if (!requireNamespace("Rcpp", quietly = TRUE)) {
-      message("Due to absence of Rcpp using vanilla EM; for faster performance install REBayes (preferred) or Rcpp")
-      optmethod = "mixEM"
-    }
-  }
-  
-  if (optmethod == "mixIP") assertthat::assert_that(requireNamespace("REBayes", quietly = TRUE))
-  if (optmethod == "cxxMixSquarem") assertthat::assert_that(requireNamespace("Rcpp", quietly = TRUE))
+  if (optmethod == "mixIP")
+    assertthat::assert_that(requireNamespace("REBayes", quietly = TRUE))
   return(optmethod)
 }
 
-
 check_lik = function(lik, betahat, sebetahat, df, mixcompdist){
   if(is.null(lik$lcdfFUN)){stop("Likelihood must have lcdfFUN")}
   if(is.null(lik$lpdfFUN)){stop("Likelihood must have lpdfFUN")}
